"""
Generated Pydantic Models

Auto-generated from RPC methods - DO NOT EDIT
Generated by: django_cfg_rpc codegen
"""

from typing import Optional, List, Dict, Any, Union
from pydantic import BaseModel, Field


{% for model in models %}
{{ model.code }}


{% endfor %}
