"""
Setup configuration for RPC Client.

Auto-generated by django_cfg_rpc codegen.
"""

from setuptools import setup, find_packages

setup(
    name="rpc-client",
    version="1.0.0",
    description="Auto-generated WebSocket RPC Client",
    author="django_cfg_rpc codegen",
    packages=find_packages(),
    install_requires=[
        "websockets>=12.0",
        "pydantic>=2.0.0",
    ],
    python_requires=">=3.10",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
    ],
)
